@@ -5,9 +5,23 @@ from django import forms
 import models
 
 
+__all__ = ("registry", "ConfigGroup", "autodiscover", )
+
+
 registry = []
 
 
+def autodiscover():
+    for models_module in models.get_apps():
+        app_name = models_module.__name__.rsplit(".", 1)[0]
+        conf_module = "%s.config" % app_name
+        try:
+            __import__(conf_module)
+        except ImportError as err:
+            if str(err) != "No module named config":
+                raise
+
+
 class ConfigManager(object):
     
     def __init__(self, name, fields):
@@ -95,14 +109,12 @@ class ConfigGroup(object):
             meta = type(name + "Meta", (ConfigGroupMeta, ), meta_attrs)()
             
             def create_getter(field_name):
-                def getter():
-                    return getattr(config_manager, field_name)
+                getter = lambda: getattr(config_manager, field_name)
                 getter.__name__ = "%s.get_%s" % (name, field_name)
                 return staticmethod(getter)
             
             def create_setter(field_name):
-                def setter(value):
-                    return setattr(config_manager, field_name, value)
+                setter = lambda val: setattr(config_manager, field_name, val)
                 setter.__name__ = "%s.set_%s" % (name, field_name)
                 return staticmethod(setter)
             
@@ -111,10 +123,10 @@ class ConfigGroup(object):
                 attrs["get_%s" % field_name] = create_getter(field_name)
                 attrs["set_%s" % field_name] = create_setter(field_name)
             
-            attrs.update(Meta=meta)
+            attrs.update(_meta=meta)
             klass = type.__new__(self, name, bases, attrs)
             
-            # we register subclass in a list to automaticly display
+            # we register subclass in a list to automatically display
             # all config forms on admin page
             if klass not in registry:
                 registry.append(klass)
@@ -123,7 +135,7 @@ class ConfigGroup(object):
         
         # getattr / setattr are passed to config manager instance
         def __getattr__(self, name):
-            return getattr(self.Meta.config_manager, name)
+            return getattr(self._meta.config_manager, name)
         
         def __setattr__(self, name, value):
-            return setattr(self.Meta.config_manager, name, value)
+            return setattr(self._meta.config_manager, name, value)
